@@ -166,7 +166,6 @@ int main(int argc, char* argv[])
         // 引数
         else {
             if(strcmp(argv[i], "--version") == 0) {
-                saphire_set_signal();
                 saphire_init(kATConsoleApp, FALSE, runtime_script, FALSE);
                 version();
                 break;
@@ -223,6 +222,9 @@ int main(int argc, char* argv[])
                         else if(strcmp(argv[i], "-Lm") == 0) {
                             gLineField = kCR;
                         }
+                        else if(strcmp(argv[i], "-La") == 0) {
+                            gLineField = kBel;
+                        }
                         else {
                             fprintf(stderr, "invalid option %s", argv[i]);
                             exit(1);
@@ -273,8 +275,6 @@ int main(int argc, char* argv[])
             (void)setpgid(0, parent_pgid);
             */
 
-            mcurses_init(code);
-            saphire_set_signal_optc();
             saphire_init(kATOptC, FALSE, runtime_script, FALSE);
 
             saphire_set_global_var("SCRIPT_FILE_NAME", file_name);
@@ -321,8 +321,6 @@ int main(int argc, char* argv[])
         (void)setpgid(0, parent_pgid);
         */
 
-        mcurses_init(code);
-        saphire_set_signal_optc();
         saphire_init(kATOptC, FALSE, runtime_script, FALSE);
         sWFd* pipeout = sWFd_new(STDOUT_FILENO);
         sRFd* pipein = sRFd_new(STDIN_FILENO);
@@ -352,9 +350,6 @@ int main(int argc, char* argv[])
     /// インタラクティブシェル開始 ///
     mreset_tty();   // 一応端末リセット
 
-    mcurses_init(code);
-
-    saphire_set_signal();
     saphire_init(kATConsoleApp, TRUE, runtime_script, TRUE);
     saphire_rehash();
     saphire_job_done = main_saphire_job_done;
@@ -368,8 +363,6 @@ int main(int argc, char* argv[])
     int histsize = atoi(getenv("SAPHIRE_HISTSIZE"));
     if(histsize < 0) histsize = 1000;
 
-    //saphire_set_signal();
-
     char* buf;
     int history_num = 0;
     while(1) {
@@ -417,10 +410,10 @@ int main(int argc, char* argv[])
             }
         }
         else if(*buf) {
-            saphire_set_signal();
             sWFd* pipeout = sWFd_new(STDOUT_FILENO);
             sRFd* pipein = sRFd_new(STDIN_FILENO);
             saphire_init_stack_frame();
+            saphire_set_signal();
             int rcode = saphire_shell(buf, "saphire", pipeout, pipein, STDERR_FILENO);
             saphire_sweep();
             sWFd_flash(pipeout);
@@ -436,6 +429,17 @@ int main(int argc, char* argv[])
                 fprintf(stderr, "run time err\n");
                 fprintf(stderr, "%s", string_c_str(gErrMsg));
             }
+            else if(rcode != 0) {
+                fprintf(stderr, "return code is not 0\n");
+                
+                /// ヒストリに追加 ///
+                add_history(buf);
+                history_num++;
+                if(history_num > histsize) {
+                    HIST_ENTRY* history = remove_history(0);
+                    free(history);
+                }
+            }
             else {
                 /// ヒストリに追加 ///
                 add_history(buf);
