@@ -19,8 +19,31 @@
     使い方のサンプルはmain.cを参考にしてください
 */
 
+extern enum eKanjiCode gKanjiCode;
+    // saphireが使うデフォルトの漢字コード
+    // 初期値はUTF8
+    // (端末の漢字コードとは別でかまわない)
+enum eLineField { kLF, kCRLF, kCR, kBel };
+extern enum eLineField gLineField;
+    // saphireが文字列処理の内部コマンドで使う改行コード
+enum eAppType { kATOptC, kATXApp, kATCursesApp, kATConsoleApp };
+    // アプリケーションの種類
+    //
+    // kATOptC コマンドラインから使う場合
+    // kATXApp Xを使っているアプリ
+    // kATCursesApp 端末制御ライブラリを使っているコンソールアプリ
+    // kATConsoleApp 端末制御ライブラリを使わないコンソールアプリ
+
+enum eRuntimeScript { kRSNoRead, kRSSource, kRSObject };
+    // ランタイムスクリプトをどうするのかの設定
+
+    // kRSNoRead 読み込まない
+    // kRSSource ソースファイルを読み込む
+    // kRSObject オブジェクトファイルを読み込む
+
+/// オブジェクトの定義
 typedef struct _sObject {
-    string_obj* mName;
+    string_obj* mName;               /// 自分の名前
     hash_obj* mGlobals;
     hash_obj* mHashs;
     hash_obj* mArrays;
@@ -64,37 +87,13 @@ void sRFd_delete(sRFd* self);
 BOOL sRFd_close(sRFd* self);
 int sRFd_read_all(sRFd* self, string_obj* str);
 int sRFd_read_all_preserve(sRFd* self, string_obj* str);
-int sRFd_read_oneline(sRFd* self, string_obj* str);
-int sRFd_read_oneline_preserve(sRFd* self, string_obj* str);
+int sRFd_read_oneline(sRFd* self, string_obj* str, enum eLineField lf);
+int sRFd_read_oneline_preserve(sRFd* self, string_obj* str, enum eLineField lf);
 int sRFd_read_all_to_buffer(sRFd* self);
 
-extern enum eKanjiCode gKanjiCode;
-    // saphireが使うデフォルトの漢字コード
-    // 初期値はUTF8
-    // (端末の漢字コードとは別でかまわない)
-enum eLineField { kLF, kCRLF, kCR };
-extern enum eLineField gLineField;
-    // saphireが文字列処理の内部コマンドで使う改行コード
-enum eAppType { kATOptC, kATXApp, kATCursesApp, kATConsoleApp };
-    // アプリケーションの種類
-    //
-    // kATOptC コマンドラインから使う場合
-    // kATXApp Xを使っているアプリ
-    // kATCursesApp 端末制御ライブラリを使っているコンソールアプリ
-    // kATConsoleApp 端末制御ライブラリを使わないコンソールアプリ
-
-enum eRuntimeScript { kRSNoRead, kRSSource, kRSObject };
-    // ランタイムスクリプトをどうするのかの設定
-
-    // kRSNoRead 読み込まない
-    // kRSSource ソースファイルを読み込む
-    // kRSObject オブジェクトファイルを読み込む
-
 void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript runtime_script, BOOL run_user_runtimescript);
     // 初期化。saphire_shellなどを実行する前に必ず必要
     // アプリケーションの種別とジョブコントロールの有無とランタイムスクリプトをどうするかを読み込むかを設定してください
-    // あと、必要な初期化は端末制御ライブラリsaphire_curses.h
-    // のmcurses_init()です。
 void saphire_final();
     // 終了化。終了時に必要
 void saphire_set_signal();
@@ -109,9 +108,7 @@ void saphire_set_signal();
     // SIGTTOU, SIGTTIN, SIGTSTP, SIGQUIT, SIGPIPE
 void saphire_set_signal_optc();
     // saphireを実行中に使うシグナルの設定を設定する。
-    // saphire_shell, saphie_shell3などのsaphireのコードを実行する前
-    // に必ず呼んでください。
-    // 呼ばれないと正しくコマンドは実行されません。
+    // -c時に使われる
 
     // 処理しているのは
     // SIGCHLD, SIGINT, SIGCONT, SIGWINCH, SIGUSR1
@@ -123,7 +120,7 @@ extern void (*saphire_set_signal_other)();
     // もし関数ポインタが代入されていたら
     // saphire_set_signalで実行される
 extern string_obj* gErrMsg;
-    // エラーが起こった時はこの配列にメッセージ入っているので出力してください
+    // エラーが起こった時はこの文字列にメッセージ入っているので出力してください
 int saphire_shell(char* command, char* title, sWFd* pipeout, sRFd* pipein, int pipeerr);
     // 文字列を読み込んで実行
     // commandは実行するコマンドの文字列。titleはタイトル
@@ -132,7 +129,6 @@ int saphire_shell(char* command, char* title, sWFd* pipeout, sRFd* pipein, int p
     // 戻り値はプログラムの終了コードだが、0以下だと
     // saphire内でエラーが起こっているのでgErrMsgをどこかに
     // 出力してください。
-    // verboseは実行しているコマンド名を表示するかどうか
 int saphire_shell3(string_obj* result, char* command, char* title, sRFd* pipein);
     // 文字列を読み込んで実行。コマンドの出力はresult
     // (saphire_string.hで定義されているstring_obj*文字列型)に入る
@@ -140,7 +136,6 @@ int saphire_shell3(string_obj* result, char* command, char* title, sRFd* pipein)
     // 起こっている
     // のでgErrMsgをどこかに出力してください。
     // resultはstring_newで領域を確保しておかないといけない
-    // verboseは実行しているコマンド名を表示するかどうか
 int saphire_load(char* fname, sWFd* pipeout, sRFd* pipein, int pipeerr);
     // スクリプトファイルを読み込んで実行
     // pipeoutは出力先。pipeinは入力先
@@ -165,9 +160,6 @@ int saphire_load_obj(char* fname, sWFd* pipeout, sRFd* pipein, int pipeerr, vect
 void saphire_wait_background_job();
     // バックグランドジョブの状態のチェック
     // ジョブ管理をする場合メインループ中に定期的に実行してください
-void saphire_wait_background_job2();
-    // バックグランドジョブの状態のチェック
-    // ジョブ管理をする場合メインループ中に定期的に実行してください
 extern void (*saphire_job_done)(int job_num, char* job_title);
     // ジョブ管理しているときにジョブが終わったら実行する処理
     // job_numに終わったジョブの番号が入いれて呼ばれる。
@@ -187,6 +179,7 @@ void saphire_kill_all_jobs();
 
 void saphire_init_stack_frame();
     // スタックフレームの初期化
+    // ローカル変数を初期化します
 
 extern vector_obj* gSaphireProgCompletions;               // 補完候補
 
@@ -210,9 +203,8 @@ void saphire_rehash2();
     // 外部コマンドはりハッシュしない
 
 extern BOOL gKitutukiExit;
-        // exit内部コマンドが呼ばれたらTRUEが入る
-        // メインループでTRUEが入っていたらプログラムを
-        // 終了してください。
+        // exit内部コマンドが呼ばれたら終了コードが入る
+        // メインループで>=0ならプログラムを終了してください。
 extern void saphire_get_quoted_fname(char* fname, string_obj* quoted_fname);
         // saphireシェルで使われる特殊な文字をクォートした文字列を返す
         // &,|,>など
@@ -236,7 +228,7 @@ typedef BOOL (*fInnerCommand)(int* rcode, vector_obj* argv, vector_obj* blocks,
         // titleはコマンドのタイトルが入っている
         // inputはパイプ処理を行う場合はTRUEになっている
         // ls | command などのcommand
-        // | command (グローバルパイプ)とかのcommandの場合はTRUE
+        // | command (コンテキストパイプ)とかのcommandの場合はTRUE
         // command | lessのcommandだとFALSE
 
 void saphire_add_inner_command(char* name, fInnerCommand fun);
@@ -279,13 +271,10 @@ typedef struct
 
 sStatments* sStatments_new();
 sStatments* sStatments_new2(sStatments* statments);
-void sStatments_delete(sStatments* self);
 BOOL saphire_compile2(char* cmdline, char* fname, sStatments* statments);
     // cmdlineのソースをコンパイルして結果をstatmentsに格納する。
     // コンパイル結果のstatmentsはsaphire_runによって実行できる。
     // statmentsはsStatments_newによって初期化されないといけない。
-    // また必要でなくなったらsStatments_deleteによって開放しないといけない。
-    // 終了時にできればsStatments_deleteしたほうがよい。
     // エラー時はgErrMsgにエラー内容が入っている
 int saphire_run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pipeerr);
 
@@ -298,8 +287,6 @@ int saphire_run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein,
 
     saphire_run(statments, "run", STDOUT_FILENO, STDIN_FILENO, STDERR_FILENO, FALSE);
 
-    sStatments_delete(statments);
-
     */
 
 // 出力をCTRL-Cで止めたいので、この関数を経由して書き込む
@@ -321,17 +308,19 @@ int statment_tree_internal_commands_read_nextin(sRFd* nextin, string_obj* str);
 int statment_tree_internal_commands_read_nextin_preserve(sRFd* nextin, string_obj* str);
 
 // 出力をCTRL-Cで止めたいので、この関数を経由して読み込む
+// 一行読み込む
 // 戻り値 -1 --> CTRL-Cで止められた
 // 戻り値 0 --> 正常終了
 // 戻り値 1 --> EOF
-int statment_tree_internal_commands_read_nextin_oneline(sRFd* nextin, string_obj* str);
+int statment_tree_internal_commands_read_nextin_oneline(sRFd* nextin, string_obj* str, enum eLineField lf);
 
 // 出力をCTRL-Cで止めたいので、この関数を経由して読み込む
+// 一行読み込み
 // 戻り値 -1 --> CTRL-Cで止められた
 // 戻り値 0 --> 正常終了
 // 戻り値 1 --> EOF
 // 読み込んでも読み込んだ分のバッファを消さない
-int statment_tree_internal_commands_read_nextin_oneline_preserve(sRFd* nextin, string_obj* str);
+int statment_tree_internal_commands_read_nextin_oneline_preserve(sRFd* nextin, string_obj* str, enum eLineField lf);
 
 void saphire_sweep();
     // ごみ掃除
