@@ -219,6 +219,9 @@ BOOL is_line_field2(enum eLineField lf, char* p)
     else if(lf == kCRLF && *p == '\r' && *(p+1) == '\n') {
         return TRUE;
     }
+    else if(lf == kBel && *p == '\a') {
+        return TRUE;
+    }
 
     return FALSE;
 }
@@ -235,12 +238,53 @@ BOOL string_chomp(string_obj* str)
 
         return TRUE;
     }
-    else if(len >= 1) {
-        if(s[len-1] == '\r' || s[len-1] == '\n') {
-            string_trunc(str, len-1);
+    else if(len >= 1 && (s[len-1] == '\r' || s[len-1] == '\n' || s[len-1] == '\a')) 
+    {
+        string_trunc(str, len-1);
+        return TRUE;
+    }
+
+    return FALSE;
+}
+
+// 改行コードを取り除く
+BOOL string_chomp2(string_obj* str, enum eLineField lf)
+{
+    char* s = string_c_str(str);
+    const int len = strlen(s);
+
+    if(lf == kCRLF) {
+        if(len >= 2 && s[len-2] == '\r' && s[len-1] == '\n')
+        {
+            string_trunc(str, len-2);
+
             return TRUE;
         }
     }
+    else if(lf == kCR) {
+        if(len >= 1) {
+            if(s[len-1] == '\r') {
+                string_trunc(str, len-1);
+                return TRUE;
+            }
+        }
+    }
+    else if(lf == kLF) {
+        if(len >= 1) {
+            if(s[len-1] == '\n') {
+                string_trunc(str, len-1);
+                return TRUE;
+            }
+        }
+    }
+    else {
+        if(len >= 1) {
+            if(s[len-1] == '\a') {
+                string_trunc(str, len-1);
+                return TRUE;
+            }
+        }
+    }
 
     return FALSE;
 }
@@ -253,7 +297,7 @@ void string_pomch(string_obj* str, enum eLineField lf)
 
     if(len >= 2 && s[len-2] == '\r' && s[len-1] == '\n') {
     }
-    else if(len >= 1 && (s[len-1] == '\r' || s[len-1] == '\n')) {
+    else if(len >= 1 && (s[len-1] == '\r' || s[len-1] == '\n' || s[len-1] == '\a')) {
     }
     else {
         if(lf == kCR) {
@@ -262,9 +306,12 @@ void string_pomch(string_obj* str, enum eLineField lf)
         else if(lf == kCRLF) {
             string_push_back(str, "\r\n");
         }
-        else {
+        else if(lf == kLF) {
             string_push_back2(str, '\n');
         }
+        else {
+            string_push_back2(str, '\a');
+        }
     }
 }
 
@@ -305,7 +352,7 @@ void saphire_get_quoted_fname(char* fname, string_obj* quoted_fname)
                 || *p=='\\' || *p=='|' || *p=='[' || *p==']' || *p=='{' 
                 || *p=='}' || *p==';'
                 || *p=='\'' || *p=='"' || *p=='<' || *p=='>' || *p=='?' 
-                || *p=='%' || *p=='@' || *p=='\n' || *p=='\t' || *p=='\r')
+                || *p=='%' || *p=='@' || *p=='\n' || *p=='\t' || *p=='\r' || *p=='\a')
         {
             string_push_back2(quoted_fname, '\\');
             string_push_back2(quoted_fname, *p++);
@@ -2565,7 +2612,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "3.2.3", 1);
+    setenv("SAPHIRE_VERSION", "3.3.1", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
@@ -2605,6 +2652,14 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
 //    saphire_rehash();
 
+    /// シグナルの設定 ///
+    if(app_type == kATOptC) {
+        saphire_set_signal_optc();
+    }
+    else {
+        saphire_set_signal();
+    }
+
     /// ランタイムスクリプト読み込み ///
     switch(runtime_script) {
         case kRSNoRead:
@@ -2634,6 +2689,9 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     tmpfile_all_sweep();
     gSaphireVarCompletions = VECTOR_NEW(100);
+
+    mcurses_init(kTKUtf8);
+    kanji_init();
 }
 
 void saphire_final()
@@ -2831,7 +2889,7 @@ int sRFd_read_all_to_buffer(sRFd* self)
 }
 
 // 0: 正常終了 1: EOF -1:エラー
-int sRFd_read_oneline(sRFd* self, string_obj* str)
+int sRFd_read_oneline(sRFd* self, string_obj* str, enum eLineField lf)
 {
     if(self->mFd == -1) {
         string_obj* buffer = self->mBuffer;
@@ -2848,18 +2906,23 @@ int sRFd_read_oneline(sRFd* self, string_obj* str)
         /// 取ったバッファから一行を得て返す ///
         char *p;
         int lf_char_size;
-        if(gLineField == kLF) {
+        if(lf == kLF) {
             p = strstr(string_c_str(buffer), "\n"); 
             lf_char_size = 1;
         }
-        else if(gLineField == kCRLF) {
+        else if(lf == kCRLF) {
             p = strstr(string_c_str(buffer), "\r\n"); 
             lf_char_size = 2;
         }
-        else {
+        
+        else if(lf == kCR) {
             p = strstr(string_c_str(buffer), "\r"); 
             lf_char_size = 1;
         }
+        else {
+            p = strstr(string_c_str(buffer), "\a"); 
+            lf_char_size = 1;
+        }
 
         /// 改行がある
         if(p) {
@@ -2882,21 +2945,26 @@ int sRFd_read_oneline(sRFd* self, string_obj* str)
     else {
         while(1) {
             /// 改行が含まれていればbreakする ///
-            if(gLineField == kCR) {
+            if(lf == kCR) {
                 if(strstr(string_c_str(self->mBuffer), "\r")) {
                     break;
                 }
             }
-            else if(gLineField == kLF) {
+            else if(lf == kLF) {
                 if(strstr(string_c_str(self->mBuffer), "\n")) {
                     break;
                 }
             }
-            else {
+            else if(lf == kCRLF) {
                 if(strstr(string_c_str(self->mBuffer), "\r\n")) {
                     break;
                 }
             }
+            else {
+                if(strstr(string_c_str(self->mBuffer), "\a")) {
+                    break;
+                }
+            }
 
             char buf[BUFSIZ+1];
 
@@ -2928,18 +2996,22 @@ int sRFd_read_oneline(sRFd* self, string_obj* str)
         /// 取ったバッファから一行を得て返す ///
         char *p;
         int lf_char_size;
-        if(gLineField == kLF) {
+        if(lf == kLF) {
             p = strstr(string_c_str(self->mBuffer), "\n"); 
             lf_char_size = 1;
         }
-        else if(gLineField == kCRLF) {
+        else if(lf == kCRLF) {
             p = strstr(string_c_str(self->mBuffer), "\r\n"); 
             lf_char_size = 2;
         }
-        else {
+        else if(lf == kCR) {
             p = strstr(string_c_str(self->mBuffer), "\r"); 
             lf_char_size = 1;
         }
+        else {
+            p = strstr(string_c_str(self->mBuffer), "\a"); 
+            lf_char_size = 1;
+        }
 
         /// 改行がある
         if(p) {
@@ -2961,7 +3033,7 @@ int sRFd_read_oneline(sRFd* self, string_obj* str)
 }
 
 // 0: 正常終了 1: EOF -1:エラー
-int sRFd_read_oneline_preserve(sRFd* self, string_obj* str)
+int sRFd_read_oneline_preserve(sRFd* self, string_obj* str, enum eLineField lf)
 {
     if(self->mFd == -1) {
         string_obj* buffer = self->mBuffer;
@@ -2978,18 +3050,22 @@ int sRFd_read_oneline_preserve(sRFd* self, string_obj* str)
         /// 取ったバッファから一行を得て返す ///
         char *p;
         int lf_char_size;
-        if(gLineField == kLF) {
+        if(lf == kLF) {
             p = strstr(string_c_str(buffer), "\n"); 
             lf_char_size = 1;
         }
-        else if(gLineField == kCRLF) {
+        else if(lf == kCRLF) {
             p = strstr(string_c_str(buffer), "\r\n"); 
             lf_char_size = 2;
         }
-        else {
+        else if(lf == kCR) {
             p = strstr(string_c_str(buffer), "\r"); 
             lf_char_size = 1;
         }
+        else {
+            p = strstr(string_c_str(buffer), "\a"); 
+            lf_char_size = 1;
+        }
 
         /// 改行がある
         if(p) {
@@ -3007,21 +3083,26 @@ int sRFd_read_oneline_preserve(sRFd* self, string_obj* str)
     else {
         while(1) {
             /// 改行が含まれていればbreakする ///
-            if(gLineField == kCR) {
+            if(lf == kCR) {
                 if(strstr(string_c_str(self->mBuffer), "\r")) {
                     break;
                 }
             }
-            else if(gLineField == kLF) {
+            else if(lf == kLF) {
                 if(strstr(string_c_str(self->mBuffer), "\n")) {
                     break;
                 }
             }
-            else {
+            else if(lf == kCRLF) {
                 if(strstr(string_c_str(self->mBuffer), "\r\n")) {
                     break;
                 }
             }
+            else {
+                if(strstr(string_c_str(self->mBuffer), "\a")) {
+                    break;
+                }
+            }
 
             char buf[BUFSIZ+1];
 
@@ -3053,17 +3134,21 @@ int sRFd_read_oneline_preserve(sRFd* self, string_obj* str)
         /// 取ったバッファから一行を得て返す ///
         char *p;
         int lf_char_size;
-        if(gLineField == kLF) {
+        if(lf == kLF) {
             p = strstr(string_c_str(self->mBuffer), "\n"); 
             lf_char_size = 1;
         }
-        else if(gLineField == kCRLF) {
+        else if(lf == kCRLF) {
             p = strstr(string_c_str(self->mBuffer), "\r\n"); 
             lf_char_size = 2;
         }
-        else {
+        else if(lf == kCR) {
             p = strstr(string_c_str(self->mBuffer), "\r"); 
             lf_char_size = 1;
+       }
+        else {
+            p = strstr(string_c_str(self->mBuffer), "\a"); 
+            lf_char_size = 1;
         }
 
         /// 改行がある
@@ -3083,7 +3168,7 @@ int sRFd_read_oneline_preserve(sRFd* self, string_obj* str)
 }
 
 // 0: 正常終了 1: EOF -1:エラー
-int sRFd_read_oneline_preserve_num(sRFd* self, string_obj* str, int line_num)
+int sRFd_read_oneline_preserve_num(sRFd* self, string_obj* str, int line_num, enum eLineField lf)
 {
     if(self->mFd == -1) {
         string_obj* buffer = self->mBuffer;
@@ -3100,7 +3185,7 @@ int sRFd_read_oneline_preserve_num(sRFd* self, string_obj* str, int line_num)
         /// 取ったバッファからn行を得て返す ///
         char *p;
         int lf_char_size;
-        if(gLineField == kLF) {
+        if(lf == kLF) {
             int i;
             p = strstr(string_c_str(buffer), "\n"); 
             for(i=0; i<line_num-1 && p != NULL; i++) {
@@ -3108,7 +3193,7 @@ int sRFd_read_oneline_preserve_num(sRFd* self, string_obj* str, int line_num)
             }
             lf_char_size = 1;
         }
-        else if(gLineField == kCRLF) {
+        else if(lf == kCRLF) {
             int i;
             p = strstr(string_c_str(buffer), "\r\n"); 
             for(i=0; i<line_num-1 && p != NULL; i++) {
@@ -3116,7 +3201,7 @@ int sRFd_read_oneline_preserve_num(sRFd* self, string_obj* str, int line_num)
             }
             lf_char_size = 2;
         }
-        else {
+        else if(lf == kCR) {
             int i;
             p = strstr(string_c_str(buffer), "\r"); 
             for(i=0; i<line_num-1 && p != NULL; i++) {
@@ -3124,6 +3209,14 @@ int sRFd_read_oneline_preserve_num(sRFd* self, string_obj* str, int line_num)
             }
             lf_char_size = 1;
         }
+        else {
+            int i;
+            p = strstr(string_c_str(buffer), "\a"); 
+            for(i=0; i<line_num-1 && p != NULL; i++) {
+                p = strstr(p+1, "\a"); 
+            }
+            lf_char_size = 1;
+        }
 
         /// 改行がある
         if(p) {
@@ -3141,7 +3234,7 @@ int sRFd_read_oneline_preserve_num(sRFd* self, string_obj* str, int line_num)
     else {
         while(1) {
             /// 改行がn個含まれていればbreakする ///
-            if(gLineField == kCR) {
+            if(lf == kCR) {
                 char* p = strstr(string_c_str(self->mBuffer), "\r");
                 int n = 0;
                 while(p != NULL && n<line_num) {
@@ -3152,7 +3245,7 @@ int sRFd_read_oneline_preserve_num(sRFd* self, string_obj* str, int line_num)
                     break;
                 }
             }
-            else if(gLineField == kLF) {
+            else if(lf == kLF) {
                 char* p = strstr(string_c_str(self->mBuffer), "\n");
                 int n = 0;
                 while(p != NULL && n<line_num) {
@@ -3163,7 +3256,7 @@ int sRFd_read_oneline_preserve_num(sRFd* self, string_obj* str, int line_num)
                     break;
                 }
             }
-            else {
+            else if(lf == kCRLF) {
                 char* p = strstr(string_c_str(self->mBuffer), "\r\n");
                 int n = 0;
                 while(p != NULL && n<line_num) 
@@ -3175,6 +3268,17 @@ int sRFd_read_oneline_preserve_num(sRFd* self, string_obj* str, int line_num)
                     break;
                 }
             }
+            else {
+                char* p = strstr(string_c_str(self->mBuffer), "\a");
+                int n = 0;
+                while(p != NULL && n<line_num) {
+                    p = strstr(p+1, "\a");
+                    n++;
+                }
+                if(n == line_num) {
+                    break;
+                }
+            }
 
             char buf[BUFSIZ+1];
 
@@ -3206,7 +3310,7 @@ int sRFd_read_oneline_preserve_num(sRFd* self, string_obj* str, int line_num)
         /// 取ったバッファからn行を得て返す ///
         char *p;
         int lf_char_size;
-        if(gLineField == kLF) {
+        if(lf == kLF) {
             int i;
             p = strstr(string_c_str(self->mBuffer), "\n"); 
             for(i=0; i<line_num-1 && p != NULL; i++) {
@@ -3214,7 +3318,7 @@ int sRFd_read_oneline_preserve_num(sRFd* self, string_obj* str, int line_num)
             }
             lf_char_size = 1;
         }
-        else if(gLineField == kCRLF) {
+        else if(lf == kCRLF) {
             int i;
             p = strstr(string_c_str(self->mBuffer), "\r\n"); 
             for(i=0; i<line_num-1 && p != NULL; i++) {
@@ -3222,7 +3326,7 @@ int sRFd_read_oneline_preserve_num(sRFd* self, string_obj* str, int line_num)
             }
             lf_char_size = 2;
         }
-        else {
+        else if(lf == kCR) {
             int i;
             p = strstr(string_c_str(self->mBuffer), "\r"); 
             for(i=0; i<line_num-1 && p != NULL; i++) {
@@ -3230,6 +3334,14 @@ int sRFd_read_oneline_preserve_num(sRFd* self, string_obj* str, int line_num)
             }
             lf_char_size = 1;
         }
+        else {
+            int i;
+            p = strstr(string_c_str(self->mBuffer), "\a"); 
+            for(i=0; i<line_num-1 && p != NULL; i++) {
+                p = strstr(p+1, "\a"); 
+            }
+            lf_char_size = 1;
+        }
 
         /// 改行がある
         if(p) {
