@@ -545,7 +545,7 @@ static BOOL statment_tree_make_argv(sCommand* command, vector_obj* argv, vector_
                 sRFd* tmp = sRFd_new2(-1, pipeout->mBuffer);
                 while(1) {
                     string_obj* str = STRING_NEW("");
-                    int ret = sRFd_read_oneline(tmp, str);
+                    int ret = sRFd_read_oneline(tmp, str, gLineField);
 
                     if(ret < -1) {
                         return FALSE;
@@ -1417,7 +1417,7 @@ void run_wait_cprogs(sStatment* statment, int* rcode, sWFd* pipeout, int last_pr
 {
     /// - バックグラウンド - ///
     if((gAppType == kATCursesApp || gAppType == kATConsoleApp) 
-        &&  statment->mBackground) 
+        && statment->mBackground) 
     {
         sJob* job = sJob_new();
 
@@ -1646,10 +1646,10 @@ int run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pip
 
         /// 大域脱出
         if(enable_return && *return_) {
-            return TRUE;
+            return rcode;
         }
         if(enable_break && *break_) {
-            return TRUE;
+            return rcode;
         }
     }
 
@@ -2032,10 +2032,8 @@ int saphire_run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein,
     int return_ = FALSE;
     int break_ = FALSE;
     vector_obj* envs = VECTOR_NEW(10);
-    int r = run(statments, title, pipeout, pipein, pipeerr
+    return run(statments, title, pipeout, pipein, pipeerr
             , &return_, TRUE, &break_, FALSE, NULL, FALSE, envs, NULL, NULL, NULL);
-
-    return r;
 }
 
 void saphire_sweep()
